from typing import List

__all__: List[str]

def sqrt(x): ...
def log(x): ...
def log10(x): ...
def logn(n, x): ...
def log2(x): ...
def power(x, p): ...
def arccos(x): ...
def arcsin(x): ...
def arctanh(x): ...
